@@ -21,3 +21,10 @@ void pacct_print_file_and_line PARAMS((FILE *out));
 #ifdef HAVE_COMP_T
 double comp_t_2_double PARAMS((comp_t));
 #endif
+
+#ifdef LINUX_MULTIFORMAT
+double comp2_t_2_double PARAMS((comp2_t val));
+size_t convert_acct_record_write PARAMS((struct acct *rec_in,
+                                        struct acct *rec_out,
+                                        int version, int byteswap));
+#endif
